@@ -11,10 +11,10 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from . import dockerrun
-from .abstractcontainer import AbstractContainer
-from ..objects.exceptions import NotFoundError
-from ..resources.strings import strings
+from ebcli.containers import dockerrun
+from ebcli.containers.abstractcontainer import AbstractContainer
+from ebcli.objects.exceptions import NotFoundError
+from ebcli.resources.strings import strings
 
 
 class GenericContainer(AbstractContainer):
@@ -23,11 +23,15 @@ class GenericContainer(AbstractContainer):
     """
 
     def validate(self):
-        if (not self.pathconfig.dockerfile_exists() and
-            not self.pathconfig.dockerrun_exists()):
+        if (
+            not self.pathconfig.dockerfile_exists()
+            and not self.pathconfig.dockerrun_exists()
+        ):
             raise NotFoundError(strings['local.filenotfound'])
-        dockerrun.validate_dockerrun_v1(self.fs_handler.dockerrun,
-                                        not self.pathconfig.dockerfile_exists())
+        dockerrun.validate_dockerrun_v1(
+            self.fs_handler.dockerrun,
+            not self.pathconfig.dockerfile_exists()
+        )
 
     # This gets called if user only provides Dockerrun.aws.json and not Dockerfile
     def _containerize(self):
