@@ -1,10 +1,22 @@
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License"). You
+# may not use this file except in compliance with the License. A copy of
+# the License is located at
+#
+# http://aws.amazon.com/apache2.0/
+#
+# or in the "license" file accompanying this file. This file is
+# distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
+# ANY KIND, either express or implied. See the License for the specific
+# language governing permissions and limitations under the License.
 from datetime import datetime
 import os
 
-from . import dockerrun
-from ..core import fileoperations, io
-from ..lib import utils
-from ..resources.strings import strings
+from ebcli.containers import dockerrun
+from ebcli.core import fileoperations, io
+from ebcli.lib import utils
+from ebcli.resources.strings import strings
 
 
 HOST_LOGS_DIRNAME = 'local'
@@ -101,13 +113,12 @@ def _get_last_local_logs(root_log):
 
 
 def _symlink_new_log_dir(root_log_dir, new_local_dir):
-    # Symlink latest
     latest_symlink_path = _symlink_path(root_log_dir)
 
     try:
         os.unlink(latest_symlink_path)
     except OSError:
-        pass  # Windows or latest_symlink_path is not a symlink
+        pass
     try:
         os.symlink(new_local_dir, latest_symlink_path)
     except OSError:
