@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -10,12 +10,12 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-from ..lib import utils
-from ..core import io
+from ebcli.lib import utils
+from ebcli.core import io
 
-from ..core.abstractcontroller import AbstractBaseController
-from ..resources.strings import strings, flag_text, prompts
-from ..operations import gitops
+from ebcli.core.abstractcontroller import AbstractBaseController
+from ebcli.resources.strings import strings, flag_text, prompts
+from ebcli.operations import gitops
 
 
 class CodeSourceController(AbstractBaseController):
@@ -23,9 +23,16 @@ class CodeSourceController(AbstractBaseController):
         label = 'codesource'
         description = strings['codesource.info']
         arguments = [
-            (['sourcename'], dict(action='store', nargs='?',
-                                    help=flag_text['codesource.sourcename'],
-                                  choices=['codecommit', 'local'], type=str.lower)),
+            (
+                ['sourcename'],
+                dict(
+                    action='store',
+                    nargs='?',
+                    help=flag_text['codesource.sourcename'],
+                    choices=['codecommit', 'local'],
+                    type=str.lower
+                )
+            ),
         ]
         usage = 'eb codesource <sourcename> [options ...]'
 
