@@ -1,4 +1,4 @@
-# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -14,13 +14,22 @@
 
 from ebcli.core import fileoperations
 from ebcli.core.abstractcontroller import AbstractBaseController
-from ebcli.operations import solution_stack_ops
-from ebcli.operations.platformops import set_platform, get_platform_name_and_version_interactive
+from ebcli.objects.platform import PlatformBranch, PlatformVersion
+from ebcli.operations.platformops import (
+    get_platform_name_and_version_interactive,
+    prompt_for_platform,
+    set_platform,
+)
+from ebcli.operations.statusops import (
+    alert_platform_branch_status,
+    alert_platform_status,
+)
 from ebcli.resources.strings import strings, flag_text
 
 
 class PlatformSelectController(AbstractBaseController):
     class Meta:
+        requires_directory_initialization = True
         label = 'platform select'
         aliases = ['select']
         aliases_only = True
@@ -32,15 +41,36 @@ class PlatformSelectController(AbstractBaseController):
         epilog = strings['platformselect.epilog']
 
     def do_command(self):
-        platform = solution_stack_ops.get_solution_stack_from_customer().name
+        platform = prompt_for_platform()
+
+        if isinstance(platform, PlatformVersion):
+            alert_platform_status(platform)
+            if platform.platform_branch_name:
+                platform = platform.platform_branch_name
+            else:
+                platform = platform.platform_name
+        elif isinstance(platform, PlatformBranch):
+            alert_platform_branch_status(platform)
+            platform = platform.branch_name
+
         fileoperations.write_config_setting('global', 'default_platform', platform)
 
 
 class GenericPlatformUseController(AbstractBaseController):
     class Meta:
+        is_platform_workspace_only_command = True
+        requires_directory_initialization = True
         description = strings['platformworkspaceselectversion.info']
         arguments = [
-            (['platform'], dict(action='store', nargs='?', default=None, help=flag_text['platformworkspace.platform'])),
+            (
+                ['platform'],
+                dict(
+                    action='store',
+                    nargs='?',
+                    default=None,
+                    help=flag_text['platformworkspace.platform']
+                )
+            ),
         ]
 
         @classmethod
@@ -54,7 +84,6 @@ class GenericPlatformUseController(AbstractBaseController):
 
         if platform_name is None:
             platform_name, platform_version = get_platform_name_and_version_interactive()
-            # The platform has already been validated
             verify = False
 
         set_platform(platform_name, platform_version, verify)
