@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -11,15 +11,15 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from ..core.abstractcontroller import AbstractBaseController
-from ..resources.strings import strings
-from ..core import io
-from .quicklink import QuicklinkController
-from .download import DownloadController
-from .convertdockerrun import ConvertDockerrunController
-from .cleanupversions import CleanupVersionsController
-from .cloudwatchsetup import CloudWatchSetUp
-from .setupssl import SetupSSLController
+from ebcli.core.abstractcontroller import AbstractBaseController
+from ebcli.resources.strings import strings
+from ebcli.core import io
+from ebcli.labs.quicklink import QuicklinkController
+from ebcli.labs.download import DownloadController
+from ebcli.labs.convertdockerrun import ConvertDockerrunController
+from ebcli.labs.cleanupversions import CleanupVersionsController
+from ebcli.labs.cloudwatchsetup import CloudWatchSetUp
+from ebcli.labs.setupssl import SetupSSLController
 
 
 class LabsController(AbstractBaseController):
@@ -34,14 +34,10 @@ class LabsController(AbstractBaseController):
         self.app.args.print_help()
 
     def complete_command(self, commands):
-        # We only care about regions
         if len(commands) == 1:
-            # They only have the main command so far
-            # lets complete for next level command
             labels = [c.Meta.label for c in self._get_child_controllers()]
             io.echo(*(label.replace('_', '-') for label in labels))
         elif len(commands) > 1:
-            # pass to next level controller
             controllers = self._get_child_controllers()
             for c in controllers:
                 if commands[1] == c.Meta.label.replace('_', '-'):
@@ -61,6 +57,5 @@ class LabsController(AbstractBaseController):
     @classmethod
     def _add_to_handler(cls, handler):
         handler.register(cls)
-        # Register child controllers
         for c in cls._get_child_controllers():
             handler.register(c)
