@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -15,7 +15,10 @@
 Apply botocore fixes as monkey patches.
 This allows us to use any version of botocore.
 """
+import datetime
+import time
 
+from dateutil import tz
 from botocore import parsers
 
 
@@ -49,22 +52,20 @@ def fix_botocore_to_pass_response_date():
             parsed = self._do_error_parse(response, shape)
         else:
             parsed = self._do_parse(response, shape)
-        # Inject HTTPStatusCode key in the response metadata if the
-        # response metadata exists.
         if isinstance(parsed, dict) and 'ResponseMetadata' in parsed:
             parsed['ResponseMetadata']['HTTPStatusCode'] = (
                 response['status_code'])
 
-            ##### BEGIN PATCH
+            # BEGIN PATCH
             # Here we inject the date
             parsed['ResponseMetadata']['date'] = (
                 response['headers']['date']
             )
-            ##### END PATCH
+            # END PATCH
         return parsed
 
     parsers.ResponseParser.parse = parse
 
 
 def apply_patches():
-    fix_botocore_to_pass_response_date()
\ No newline at end of file
+    fix_botocore_to_pass_response_date()
