@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -62,8 +62,13 @@ class EnvironmentSettings(ConversionConfiguration):
                             changes.append(setting)
                         else:
                             remove.append(
-                                _get_option_setting_dict(namespace, option,
-                                                              None, resource_name))
+                                _get_option_setting_dict(
+                                    namespace,
+                                    option,
+                                    None,
+                                    resource_name
+                                )
+                            )
                 else:
                     if usr_value is not None:
                         setting['Value'] = usr_value
@@ -71,8 +76,12 @@ class EnvironmentSettings(ConversionConfiguration):
 
             except KeyError:
                 # user removed setting. We want to add to remove list
-                d = _get_option_setting_dict(namespace, option,
-                                                  None, resource_name)
+                d = _get_option_setting_dict(
+                    namespace,
+                    option,
+                    None,
+                    resource_name
+                )
                 remove.append(d)
 
         # Now we look for added options:
@@ -111,7 +120,6 @@ class EnvironmentSettings(ConversionConfiguration):
             if 'ResourceName' in setting:
                 namespace = setting['ResourceName'] + '.' + namespace
             if namespace not in usr_model_settings:
-                # create it
                 usr_model_settings[namespace] = dict()
 
             key = setting['OptionName']
