@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -10,20 +10,15 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-
-import time
-
-from ..lib import elasticbeanstalk
-from ..core import io
-from ..objects.exceptions import TimeoutError
-from ..resources.strings import strings
-from . import commonops
+from ebcli.lib import elasticbeanstalk
+from ebcli.core import io
+from ebcli.operations import commonops
 
 
 def compose(app_name, version_labels, grouped_env_names, group_name=None,
             nohang=False, timeout=None):
 
-    success = commonops.wait_for_processed_app_versions(app_name, version_labels)
+    success = commonops.wait_for_processed_app_versions(app_name, version_labels, timeout=timeout or 10)
     if not success:
         return
 
@@ -48,4 +43,3 @@ def compose_no_events(app_name, version_labels, group_name=None):
         return None
 
     return compose_apps(app_name, version_labels, group_name)
-
