@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -10,33 +10,18 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-
-import re
-
 from cement.utils.misc import minimal_logger
 
-from ..core import fileoperations, io
-from ..lib import elasticbeanstalk, heuristics, aws, codebuild
-from ..objects.exceptions import CredentialsError, NotAuthorizedError
-from ..objects.sourcecontrol import SourceControl
-from ..resources.strings import strings
+from ebcli.core import fileoperations, io
+from ebcli.lib import elasticbeanstalk, heuristics, aws, codebuild
+from ebcli.objects.exceptions import CredentialsError, NotAuthorizedError
+from ebcli.objects.sourcecontrol import SourceControl
+from ebcli.resources.strings import strings
 from ebcli.core.ebglobals import Constants
 
 LOG = minimal_logger(__name__)
 
 
-def credentials_are_valid():
-    try:
-        elasticbeanstalk.get_available_solution_stacks(fail_on_empty_response=False)
-        return True
-    except CredentialsError:
-        return False
-    except NotAuthorizedError as e:
-        io.log_error('The current user does not have the correct permissions. '
-                     'Reason: {0}'.format(e.message))
-        return False
-
-
 def setup(
         app_name,
         region,
@@ -61,35 +46,17 @@ def setup(
         repository=repository,
         branch=branch)
 
-    # Handle tomcat special case
-    if solution is not None and 'tomcat' in solution.lower() and \
-                heuristics.has_tomcat_war_file():
+    if (
+        solution is not None
+        and 'tomcat' in solution.lower()
+        and heuristics.has_tomcat_war_file()
+    ):
         war_file = fileoperations.get_war_file_location()
         fileoperations.write_config_setting('deploy', 'artifact', war_file)
 
     setup_ignore_file()
 
 
-def setup_credentials(access_id=None, secret_key=None):
-    io.log_info('Setting up ~/aws/ directory with config file')
-
-    if access_id is None or secret_key is None:
-        io.echo(strings['cred.prompt'])
-
-    if access_id is None:
-        access_id = io.prompt('aws-access-id',
-                              default='ENTER_AWS_ACCESS_ID_HERE')
-    if secret_key is None:
-        secret_key = io.prompt('aws-secret-key', default='ENTER_SECRET_HERE')
-
-    fileoperations.save_to_aws_config(access_id, secret_key)
-
-    fileoperations.touch_config_folder()
-    fileoperations.write_config_setting('global', 'profile', 'eb-cli')
-
-    aws.set_session_creds(access_id, secret_key)
-
-
 def setup_directory(
         app_name,
         region,
